==> haskell-ghc-typelits-natnormalise-0.7.11-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-natnormalise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-typelits-natnormalise
version:              0.7.11
visibility:           public
id:                   ghc-typelits-natnormalise-0.7.11-DODCVSjmArWJ3JPwC9bsb6
key:                  ghc-typelits-natnormalise-0.7.11-DODCVSjmArWJ3JPwC9bsb6
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             GHC typechecker plugin for types of kind GHC.TypeLits.Nat
description:
    A type checker plugin for GHC that can solve /equalities/ and /inequalities/
    of types of kind @Nat@, where these types are either:

    * Type-level naturals

    * Type variables

    * Applications of the arithmetic expressions @(+,-,*,^)@.

    It solves these equalities by normalising them to /sort-of/ @SOP@
    (Sum-of-Products) form, and then perform a simple syntactic equality.

    For example, this solver can prove the equality between:

    @
    (x + 2)^(y + 2)
    @

    and

    @
    4*x*(2 + x)^y + 4*(2 + x)^y + (2 + x)^y*x^2
    @

    Because the latter is actually the @SOP@ normal form of the former.

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Normalise
    @

    Pragma to the header of your file.

category:             Type System
abi:                  a9fa0f0848a98ea00b9b5705fdff591f
exposed:              True
exposed-modules:
    GHC.TypeLits.Normalise GHC.TypeLits.Normalise.SOP
    GHC.TypeLits.Normalise.Unify

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-typelits-natnormalise-0.7.11

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-typelits-natnormalise-0.7.11

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-typelits-natnormalise-0.7.11

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-typelits-natnormalise
hs-libraries:         HSghc-typelits-natnormalise-0.7.11-DODCVSjmArWJ3JPwC9bsb6
depends:
    base-4.17.2.1 containers-0.6.7 ghc-9.4.8 ghc-bignum-1.3
    ghc-tcplugins-extra-0.5-EDn2S7kYpSB4bldauH9edX
    template-haskell-2.19.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-natnormalise/html/ghc-typelits-natnormalise.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-natnormalise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-natnormalise-0.7.11-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-typelits-natnormalise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-typelits-natnormalise
version:              0.7.11
visibility:           public
id:                   ghc-typelits-natnormalise-0.7.11-6GpMhLpNSkBEpusfMpYyef
key:                  ghc-typelits-natnormalise-0.7.11-6GpMhLpNSkBEpusfMpYyef
license:              BSD-2-Clause
copyright:
    Copyright © 2015-2016, University of Twente,
    2017-2018, QBayLogic B.V.

maintainer:           christiaan.baaij@gmail.com
author:               Christiaan Baaij
homepage:             http://www.clash-lang.org/
synopsis:             GHC typechecker plugin for types of kind GHC.TypeLits.Nat
description:
    A type checker plugin for GHC that can solve /equalities/ and /inequalities/
    of types of kind @Nat@, where these types are either:

    * Type-level naturals

    * Type variables

    * Applications of the arithmetic expressions @(+,-,*,^)@.

    It solves these equalities by normalising them to /sort-of/ @SOP@
    (Sum-of-Products) form, and then perform a simple syntactic equality.

    For example, this solver can prove the equality between:

    @
    (x + 2)^(y + 2)
    @

    and

    @
    4*x*(2 + x)^y + 4*(2 + x)^y + (2 + x)^y*x^2
    @

    Because the latter is actually the @SOP@ normal form of the former.

    To use the plugin, add the

    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Normalise
    @

    Pragma to the header of your file.

category:             Type System
abi:                  61742a6161bfa1c85923e6ba5f1e4167
exposed:              True
exposed-modules:
    GHC.TypeLits.Normalise GHC.TypeLits.Normalise.SOP
    GHC.TypeLits.Normalise.Unify

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-typelits-natnormalise-0.7.11

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-typelits-natnormalise-0.7.11

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/ghc-typelits-natnormalise-0.7.11

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-typelits-natnormalise
hs-libraries:         HSghc-typelits-natnormalise-0.7.11-6GpMhLpNSkBEpusfMpYyef
depends:
    base-4.17.2.1 containers-0.6.7 ghc-9.4.8 ghc-bignum-1.3
    ghc-tcplugins-extra-0.5-EDn2S7kYpSB4bldauH9edX
    template-haskell-2.19.0.0 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-typelits-natnormalise/html/ghc-typelits-natnormalise.haddock

haddock-html:         /usr/share/doc/haskell-ghc-typelits-natnormalise/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
